Extracts the trainable Random Fourier Feature weights and biases from a KAF model.
Arguments
- object
A fitted object returned by
kaf_fit(), or a rawnn_kaftorch module.- layer
Optional integer. If supplied, only extract parameters from this layer.
Extracts the trainable Random Fourier Feature weights and biases from a KAF model.
A fitted object returned by kaf_fit(), or a raw nn_kaf
torch module.
Optional integer. If supplied, only extract parameters from this layer.